@@ -65,11 +65,15 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
     version = config['ip_version'] if 'ip_version' in config else None
     description = config['ip_descr'] if 'ip_descr' in config else None
     vendor = config['ip_vendor'] if 'ip_vendor' in config else None
-    pipeline_depth = int(config['pipeline_depth']) if 'pipeline_depth' in config else None
+    latency = int(config['latency']) if 'latency' in config else None
     hdl_name = config['hdl'] if 'hdl' in config else 'vhdl'
     hdl = vivado_exp.HDL.VERILOG if hdl_name == 'verilog' else vivado_exp.HDL.VHDL
-    stop_at_syn_stage = (config['syn_only'].strip().lower() == "true") if 'syn_only' in config else False
-    exp_type = vivado_exp.ExperienceType.SYNTHESIS if stop_at_syn_stage else vivado_exp.ExperienceType.IMPLEMENTATION
+    no_pipeline = (config['no_pipeline'].strip().lower() == "true") if 'no_pipeline' in config else False
+    ap_ctrl_hs = (config['ctrl_hs'].strip().lower() == "true") if 'ctrl_hs' in config else False
+    exp_type_dict = {'hls' : vivado_exp.ExperienceType.CSYNTH_ONLY,
+                     'syn' : vivado_exp.ExperienceType.SYNTHESIS,
+                     'impl': vivado_exp.ExperienceType.IMPLEMENTATION}
+    exp_type = exp_type_dict[config['exp_type']] if 'exp_type' in config else vivado_exp.ExperienceType.IMPLEMENTATION
     exp = vivado_exp.Experiment(
         name,
         comp_path,
@@ -79,6 +83,8 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
         standard,
         hdl,
         exp_type,
+        not no_pipeline,
+        ap_ctrl_hs,
         keep_env,
         description=description,
         version=version,
@@ -88,10 +94,10 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
     exp.add_defines(defines)
     exp.add_includes(includes)
     if export_hls:
-        exp.add_before_del(vivado_exp.build_get_hls())
+        exp.add_before_del(vivado_exp.build_get_hls(exp))
 
     if export_ip:
-        exp.add_before_del(vivado_exp.build_get_export_ip())
+        exp.add_before_del(vivado_exp.build_get_export_ip(exp))
 
     dispatch = {
         CommandType.MINIMIZE : run_minimize,
@@ -118,7 +124,7 @@ def handle_args(args):
     }
     command = association[args.command]
     export_hls = args.export_hls_files
-    export_ip = args.export_hls_files
+    export_ip = args.export_ip
     for s in config.sections():
         run_meta_exp(s, config[s], ini_file.parent.resolve(), command,
                      export_hls, export_ip)
